# Copyright (c) 2019 SAP SE or an SAP affiliate company. All rights reserved. This file is licensed
# under the Apache Software License, v. 2 except as noted otherwise in the LICENSE file
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from model.base import (
    NamedModelElement,
    ModelDefaultsMixin,
)


class WebhookDispatcherConfig(NamedModelElement, ModelDefaultsMixin):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._apply_defaults(self.raw)

    def _required_attributes(self):
        return {
            'concourse_config_names',
        }

    def _defaults_dict(self):
        return {
            'pipeline_templates_path': ['/cc/utils/concourse/templates'],
            'pipeline_include_path': '/cc/utils/concourse',
        }

    def pipeline_templates_path(self):
        return self.raw['pipeline_templates_path']

    def pipeline_include_path(self):
        return self.raw['pipeline_include_path']

    def concourse_config_names(self):
        return self.raw['concourse_config_names']


class WebhookDispatcherDeploymentConfig(NamedModelElement):
    def _required_attributes(self):
        return {
            'image_reference',
            'ingress_host',
            'external_url',
            'tls_config',
            'secrets_server_config',
            'kubernetes_config',
            'webhook_dispatcher_config',
            'container_port',
            'logging_els_index',
        }

    def image_reference(self):
        return self.raw.get('image_reference')

    def external_url(self):
        return self.raw.get('external_url')

    def ingress_host(self):
        return self.raw.get('ingress_host')

    def tls_config_name(self):
        return self.raw.get('tls_config')

    def secrets_server_config_name(self):
        return self.raw.get('secrets_server_config')

    def kubernetes_config_name(self):
        return self.raw.get('kubernetes_config')

    def webhook_dispatcher_config_name(self):
        return self.raw.get('webhook_dispatcher_config')

    def webhook_dispatcher_container_port(self):
        return self.raw['container_port']

    def logging_els_index(self):
        '''Name of the elastic-search index to log into'''
        return self.raw['logging_els_index']
